@@ -23,4 +23,11 @@ class Model(Base):
     updated_at = Column(DateTime(timezone=True), server_default=func.now(), server_onupdate=func.now())
 
 class View(Base):
-    __abstract__ = True
\ No newline at end of file
+    __abstract__ = True
+
+
+class Team(Model):
+    __tablename__ = 'teams'
+    __keys__ = 'name'
+
+    name = Column(String(255), unique=True)
\ No newline at end of file
