@@ -23,7 +23,7 @@ import base64
 
 class Selenium(Scraper):
 
-    def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None, disable_javascript: bool=False):
+    def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None, disable_javascript: bool=False, proxy_address: str=None):
         
         url = config.get(section='SELENIUM', key='url')
 
@@ -38,6 +38,9 @@ class Selenium(Scraper):
             options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
 
         #region options
+        if proxy_address is not None:
+            options.add_argument(f'--proxy-server={proxy_address}')
+
         if disable_javascript is True:
             options.add_experimental_option('prefs', { 'profile.managed_default_content_settings.javascript': 2 })
 
